Saraki
======


Welcome to this documentation. Saraki is a framework for
multi-tenant application.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quick
   auth


Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
